=============================================
API documentation for interacting with Galaxy
=============================================

GalaxyInstance
--------------

.. autoclass:: bioblend.galaxy.GalaxyInstance

    .. automethod:: bioblend.galaxy.GalaxyInstance.__init__

-----

.. _libraries-api:

Libraries
---------

.. automodule:: bioblend.galaxy.libraries

-----

Histories
---------

.. automodule:: bioblend.galaxy.histories

-----

.. _workflows-api:

Workflows
---------

.. automodule:: bioblend.galaxy.workflows

-----

Datasets
--------

.. automodule:: bioblend.galaxy.datasets

-----

Users
-----

.. automodule:: bioblend.galaxy.users

